# Get a list of all user profiles on the computer
$userProfiles = Get-WmiObject -Class Win32_UserProfile

foreach ($profile in $userProfiles) {
    $userSID = $profile.SID
    $userAccount = $null

    # Try to get the user account associated with the profile
    try {
        $userAccount = [System.Security.Principal.SecurityIdentifier]::new($userSID).Translate([System.Security.Principal.NTAccount]).Value
    } catch {
        # An exception occurs when the user account doesn't exist
    }

    # Check if a user account was found
    if ($userAccount -eq $null) {
        # Delete the user profile
        Write-Host "Deleting user profile with SID $userSID"
        Remove-WmiObject -InputObject $profile
    }
}

Write-Host "User profiles cleanup completed."